@@ -126,6 +126,10 @@ Event_HandleEvent(EventSelector *es)
 
     EVENT_DEBUG(("Enter Event_HandleEvent(es=%p)\n", (void *) es));
 
+    /* Silence stupid compiler warning */
+    abs_timeout.tv_sec = 0;
+    abs_timeout.tv_usec = 0;
+
     /* Build the select sets */
     FD_ZERO(&readfds);
     FD_ZERO(&writefds);
