@@ -65,7 +65,8 @@ extern int remove_local_socket(char const *str);
 #ifdef EMBED_PERL
 extern int make_embedded_interpreter(char const *progPath,
 				     char const *subFilter,
-				     int wantStatusReports);
+				     int wantStatusReports,
+				     char **env);
 extern void run_embedded_filter(void);
 extern void dump_milter_buildlib_info(void);
 
